# Copyright (c) 2019 Leiden University Medical Center
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import os

from setuptools import Extension, find_packages, setup

with open("README.rst", "r") as readme_file:
    LONG_DESCRIPTION = readme_file.read()

NO_CYTHON = bool(os.environ.get("NO_CYTHON"))


def modules():
    if NO_CYTHON:
        return []
    else:
        return [
            Extension("fastqsplitter.split_cy",
                      ["src/fastqsplitter/split_cy.pyx"])
        ]


setup(
    name="fastqsplitter",
    version="1.2.0",
    description="Splits FASTQ files evenly.",
    author="Leiden University Medical Center",
    author_email="sasc@lumc.nl",  # A placeholder for now
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/x-rst",
    license="MIT",
    keywords="fastq split",
    zip_safe=False,
    packages=find_packages('src'),
    package_dir={'': 'src'},
    # This makes sure source is included in the binary distribution
    package_data={'fastqsplitter': ['*.pyx']},
    url="https://github.com/LUMC/fastqsplitter",
    classifiers=[
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Cython",
        "License :: OSI Approved :: MIT License",
        "Topic :: Scientific/Engineering :: Bio-Informatics"
    ],
    python_requires=">=3.5",  # Because we use type annotation.
    setup_requires=[] if NO_CYTHON else ["cython"],
    install_requires=[
       "xopen>=0.8.1"
    ],
    entry_points={
        "console_scripts": [
            'fastqsplitter=fastqsplitter:main'
        ]
    },
    ext_modules=modules()
)
